Submitting an interactive figure to AAS Journals
================================================

To include an interactive figure in your paper, first make sure you export
the interactive figure(s) you have produced to a zip file (see also
:doc:`saving`)::

    fig.export_interactive_bundle('my_figure.zip')

and also be sure to export a static version of the figure for the PDF version
of the paper::

    fig.save_static('my_figure', format='pdf')

The workflow to include your figure in the paper will be added here in the near
future.
